"""
:authors: ZHRXXgroup
:license: MIT License

:copyright: (c) ZHRXXgroup
"""

from Slame import (ZHRXX, Work_with_Database,Sessions, Plugins)


__author__ = 'ZHRXXgroup'
__version__ = '1.3.6'
__email__ = 'info@zhrxxgroup.com'


class Plugins(slame.Plugins):
	...

class ZHRXX(slame.ZHRXX):
	...

class Sessions(slame.Sessions):
	...

class Work_with_Database(slame.Work_with_Database):
	...

